@@ -47,6 +47,8 @@
 static gboolean
 gnm_filter_op_needs_value (GnmFilterOp op)
 {
+	g_return_val_if_fail (op != GNM_FILTER_UNUSED, FALSE);
+
 	switch (op & GNM_FILTER_OP_TYPE_MASK) {
 	case GNM_FILTER_OP_TYPE_OP:
 	case GNM_FILTER_OP_TYPE_BUCKETS:
@@ -75,7 +77,8 @@ gnm_filter_condition_new_single (GnmFilterOp op, GnmValue *v)
 {
 	GnmFilterCondition *res;
 
-	g_return_val_if_fail ((v != NULL) == gnm_filter_op_needs_value (op), NULL);
+	g_return_val_if_fail ((v != NULL) == gnm_filter_op_needs_value (op),
+			      (value_release (v), NULL));
 
 	res = g_new0 (GnmFilterCondition, 1);
 	res->op[0] = op;	res->op[1] = GNM_FILTER_UNUSED;
@@ -101,8 +104,10 @@ gnm_filter_condition_new_double (GnmFilterOp op0, GnmValue *v0,
 {
 	GnmFilterCondition *res;
 
-	g_return_val_if_fail ((v0 != NULL) == gnm_filter_op_needs_value (op0), NULL);
-	g_return_val_if_fail ((v1 != NULL) == gnm_filter_op_needs_value (op1), NULL);
+	g_return_val_if_fail ((v0 != NULL) == gnm_filter_op_needs_value (op0),
+			      (value_release (v0), value_release (v1), NULL));
+	g_return_val_if_fail ((v1 != NULL) == gnm_filter_op_needs_value (op1),
+			      (value_release (v0), value_release (v1), NULL));
 
 	res = g_new0 (GnmFilterCondition, 1);
 	res->op[0] = op0;	res->op[1] = op1;
